@@ -22,9 +22,9 @@
 
 #include <glib/gi18n.h>
 #include <string.h>
-#include <eel/eel-alert-dialog.h>
 #include <libgnomeui/gnome-icon-lookup.h>
-#include <libgnomevfs/gnome-vfs.h>
+#include <gio/gio.h>
+#include <gdk/gdk.h>
 #include <unistd.h>
 
 #include "slab-gnome-util.h"
@@ -48,7 +48,7 @@ static GtkWidget *create_header (const gchar *);
 
 static void header_size_allocate_cb (GtkWidget *, GtkAllocation *, gpointer);
 
-static void open_trigger (Tile *, TileEvent *, TileAction *);
+static void open_with_default_trigger (Tile *, TileEvent *, TileAction *);
 static void rename_trigger (Tile *, TileEvent *, TileAction *);
 static void move_to_trash_trigger (Tile *, TileEvent *, TileAction *);
 static void delete_trigger (Tile *, TileEvent *, TileAction *);
@@ -63,12 +63,12 @@ static void disown_spawned_child (gpointer);
 typedef struct
 {
 	gchar *basename;
-	
-	GtkBin *header_bin;
-
+	gchar *mime_type;
 	gchar *icon_name;
 	
-	gboolean renaming;
+	GtkBin *header_bin;
+	GAppInfo *default_app;
+	
 	gboolean image_is_broken;
 	
 	gboolean delete_enabled;
@@ -90,7 +90,7 @@ static void directory_tile_class_init (DirectoryTileClass *this_class)
 }
 
 GtkWidget *
-directory_tile_new (const gchar *in_uri, const gchar *title, const gchar *icon_name)
+directory_tile_new (const gchar *in_uri, const gchar *title, const gchar *icon_name, const gchar *mime_type)
 {
 	DirectoryTile *this;
 	DirectoryTilePrivate *priv;
@@ -121,7 +121,7 @@ directory_tile_new (const gchar *in_uri, const gchar *title, const gchar *icon_n
 
 	if (! title) {
 		markup = g_path_get_basename (uri);
-		basename = gnome_vfs_unescape_string (markup, NULL);
+		basename = g_uri_unescape_string (markup, NULL);
 		g_free (markup);
 	}
 	else
@@ -157,6 +157,7 @@ directory_tile_new (const gchar *in_uri, const gchar *title, const gchar *icon_n
 	priv->basename    = g_strdup (basename);
 	priv->header_bin  = GTK_BIN (header);
 	priv->icon_name   = g_strdup (icon_name);
+	priv->mime_type   = g_strdup (mime_type);
 
 	directory_tile_private_setup (this);
 
@@ -168,7 +169,7 @@ directory_tile_new (const gchar *in_uri, const gchar *title, const gchar *icon_n
 	/* make open with default action */
 
 	markup = g_markup_printf_escaped (_("<b>Open</b>"));
-	action = tile_action_new (TILE (this), open_trigger, markup, TILE_ACTION_OPENS_NEW_WINDOW);
+	action = tile_action_new (TILE (this), open_with_default_trigger, markup, TILE_ACTION_OPENS_NEW_WINDOW);
 	g_free (markup);
 
 	TILE (this)->default_action = action;
@@ -258,11 +259,12 @@ static void
 directory_tile_private_setup (DirectoryTile *tile)
 {
 	DirectoryTilePrivate *priv = DIRECTORY_TILE_GET_PRIVATE (tile);
-
 	GConfClient *client;
 
-
-	priv->renaming = FALSE;
+	if (priv->mime_type)
+		priv->default_app = g_app_info_get_default_for_type (priv->mime_type, TRUE);
+	else
+		priv->default_app = NULL;
 
 	priv->delete_enabled =
 		(gboolean) GPOINTER_TO_INT (get_gconf_value (GCONF_ENABLE_DELETE_KEY));
@@ -281,10 +283,11 @@ directory_tile_init (DirectoryTile *tile)
 {
 	DirectoryTilePrivate *priv = DIRECTORY_TILE_GET_PRIVATE (tile);
 
+	priv->default_app = NULL;
 	priv->basename = NULL;
 	priv->header_bin = NULL;
 	priv->icon_name = NULL;
-	priv->renaming = FALSE;
+	priv->mime_type = NULL;
 	priv->image_is_broken = TRUE;
 	priv->delete_enabled = FALSE;
 	priv->gconf_conn_id = 0;
@@ -299,7 +302,10 @@ directory_tile_finalize (GObject *g_object)
 
 	g_free (priv->basename);
 	g_free (priv->icon_name);
+	g_free (priv->mime_type);
 
+	g_object_unref (priv->default_app);
+    
 	client = gconf_client_get_default ();
 
 	gconf_client_notify_remove (client, priv->gconf_conn_id);
@@ -362,41 +368,48 @@ rename_entry_activate_cb (GtkEntry *entry, gpointer user_data)
 	DirectoryTile *tile = DIRECTORY_TILE (user_data);
 	DirectoryTilePrivate *priv = DIRECTORY_TILE_GET_PRIVATE (tile);
 
-	GnomeVFSURI *src_uri;
-	GnomeVFSURI *dst_uri;
+	GFile *src_file;
+	GFile *dst_file;
 
 	gchar *dirname;
-	gchar *dst_path;
-	gchar *dst_uri_str;
+	gchar *dst_uri;
+	gchar *src_path;
 
 	GtkWidget *child;
 	GtkWidget *header;
 
-	GnomeVFSResult retval;
-
+	gboolean res;
+	GError *error = NULL;
 
 	if (strlen (gtk_entry_get_text (entry)) < 1)
 		return;
 
-	src_uri = gnome_vfs_uri_new (TILE (tile)->uri);
+	src_file = g_file_new_for_uri (TILE (tile)->uri);
 
-	dirname = gnome_vfs_uri_extract_dirname (src_uri);
+	src_path = g_filename_from_uri (TILE (tile)->uri, NULL, NULL);
+	dirname = g_path_get_dirname (src_path);
+	dst_uri = g_build_filename (dirname, gtk_entry_get_text (entry), NULL);
+	dst_file = g_file_new_for_uri (dst_uri);
 
-	dst_path = g_build_filename (dirname, gtk_entry_get_text (entry), NULL);
+	g_free (dirname);
+	g_free (src_path);
 
-	dst_uri = gnome_vfs_uri_new (dst_path);
+	res = g_file_move (src_file, dst_file,
+			   G_FILE_COPY_NONE, NULL, NULL, NULL, &error);
 
-	retval = gnome_vfs_xfer_uri (src_uri, dst_uri, GNOME_VFS_XFER_REMOVESOURCE,
-		GNOME_VFS_XFER_ERROR_MODE_ABORT, GNOME_VFS_XFER_OVERWRITE_MODE_SKIP, NULL, NULL);
-
-	dst_uri_str = gnome_vfs_uri_to_string (dst_uri, GNOME_VFS_URI_HIDE_NONE);
-
-	if (retval == GNOME_VFS_OK) {
+	if (res) {
 		g_free (priv->basename);
 		priv->basename = g_strdup (gtk_entry_get_text (entry));
 	}
-	else
-		g_warning ("unable to move [%s] to [%s]\n", TILE (tile)->uri, dst_uri_str);
+	else {
+		g_warning ("unable to move [%s] to [%s]: %s\n", TILE (tile)->uri, dst_uri,
+			   error->message);
+		g_error_free (error);
+	}
+
+	g_free (dst_uri);
+	g_object_unref (src_file);
+	g_object_unref (dst_file);
 
 	header = gtk_label_new (priv->basename);
 	gtk_misc_set_alignment (GTK_MISC (header), 0.0, 0.5);
@@ -409,13 +422,6 @@ rename_entry_activate_cb (GtkEntry *entry, gpointer user_data)
 	gtk_container_add (GTK_CONTAINER (priv->header_bin), header);
 
 	gtk_widget_show (header);
-
-	gnome_vfs_uri_unref (src_uri);
-	gnome_vfs_uri_unref (dst_uri);
-
-	g_free (dirname);
-	g_free (dst_path);
-	g_free (dst_uri_str);
 }
 
 static gboolean
@@ -463,19 +469,6 @@ gconf_enable_delete_cb (GConfClient *client, guint conn_id, GConfEntry *entry, g
 	}
 }
 
-static void
-open_trigger (Tile *tile, TileEvent *event, TileAction *action)
-{
-	gchar *cmd;
-
-	cmd = string_replace_once (
-		get_slab_gconf_string (SLAB_FILE_MANAGER_OPEN_CMD), "FILE_URI", tile->uri);
-
-	spawn_process (cmd);
-
-	g_free (cmd);
-}
-
 static void
 rename_trigger (Tile *tile, TileEvent *event, TileAction *action)
 {
@@ -508,76 +501,36 @@ rename_trigger (Tile *tile, TileEvent *event, TileAction *action)
 static void
 move_to_trash_trigger (Tile *tile, TileEvent *event, TileAction *action)
 {
-	GnomeVFSURI *src_uri;
-	GnomeVFSURI *trash_uri;
+	GFile *src_file;
+	gboolean res;
+	GError *error = NULL;
 
-	gchar *file_name;
-	gchar *trash_uri_str;
+	src_file = g_file_new_for_uri (TILE (tile)->uri);
 
-	GnomeVFSResult retval;
-
-
-	src_uri = gnome_vfs_uri_new (TILE (tile)->uri);
-
-	gnome_vfs_find_directory (src_uri, GNOME_VFS_DIRECTORY_KIND_TRASH, &trash_uri,
-		FALSE, FALSE, 0777);
-
-	if (!trash_uri) {
-		g_warning ("unable to find trash location\n");
-
-		return;
+	res = g_file_trash (src_file, NULL, &error);
+	if (!res) {
+		g_warning ("unable to move [%s] to the trash: %s\n", TILE (tile)->uri,
+			   error->message);
+		g_error_free (error);
 	}
 
-	file_name = gnome_vfs_uri_extract_short_name (src_uri);
-
-	if (!file_name) {
-		g_warning ("unable to extract short name from [%s]\n",
-			gnome_vfs_uri_to_string (src_uri, GNOME_VFS_URI_HIDE_NONE));
-
-		return;
-	}
-
-	trash_uri = gnome_vfs_uri_append_file_name (trash_uri, file_name);
-
-	retval = gnome_vfs_xfer_uri (src_uri, trash_uri, GNOME_VFS_XFER_REMOVESOURCE,
-		GNOME_VFS_XFER_ERROR_MODE_ABORT, GNOME_VFS_XFER_OVERWRITE_MODE_REPLACE, NULL, NULL);
-
-	if (retval != GNOME_VFS_OK) {
-		trash_uri_str = gnome_vfs_uri_to_string (trash_uri, GNOME_VFS_URI_HIDE_NONE);
-
-		g_warning ("unable to move [%s] to the trash [%s]\n", TILE (tile)->uri,
-			trash_uri_str);
-
-		g_free (trash_uri_str);
-	}
-
-	gnome_vfs_uri_unref (src_uri);
-	gnome_vfs_uri_unref (trash_uri);
-
-	g_free (file_name);
+	g_object_unref (src_file);
 }
 
 static void
 delete_trigger (Tile *tile, TileEvent *event, TileAction *action)
 {
-	gchar     *prompt;
 	GtkDialog *confirm_dialog;
 	gint       result;
 
-	GnomeVFSURI *src_uri;
-	GList *list = NULL;
-
-	GnomeVFSResult retval;
-
+	GFile *src_file;
+	gboolean res;
+	GError *error = NULL;
 
 	if (GPOINTER_TO_INT (libslab_get_gconf_value (GCONF_CONFIRM_DELETE_KEY))) {
-		prompt = g_strdup_printf (
-			_("Are you sure you want to permanently delete \"%s\"?"),
-			DIRECTORY_TILE_GET_PRIVATE (tile)->basename);
-
-		confirm_dialog = GTK_DIALOG (eel_alert_dialog_new (
-			NULL, 0, GTK_MESSAGE_WARNING, GTK_BUTTONS_NONE,
-			prompt, _("If you delete an item, it is permanently lost.")));
+		confirm_dialog = GTK_DIALOG(gtk_message_dialog_new (NULL, 0, GTK_MESSAGE_WARNING, 
+				GTK_BUTTONS_NONE, _("Are you sure you want to permanently delete \"%s\"?"), DIRECTORY_TILE_GET_PRIVATE (tile)->basename));
+		gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG(confirm_dialog), _("If you delete an item, it is permanently lost."));
 							
 		gtk_dialog_add_button (confirm_dialog, GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL);
 		gtk_dialog_add_button (confirm_dialog, GTK_STOCK_DELETE, GTK_RESPONSE_YES);
@@ -586,24 +539,22 @@ delete_trigger (Tile *tile, TileEvent *event, TileAction *action)
 		result = gtk_dialog_run (confirm_dialog);
 
 		gtk_widget_destroy (GTK_WIDGET (confirm_dialog));
-		g_free (prompt);
 
 		if (result != GTK_RESPONSE_YES)
 			return;
 	}
 
-	src_uri = gnome_vfs_uri_new (TILE (tile)->uri);
+	src_file = g_file_new_for_uri (TILE (tile)->uri);
 
-	list = g_list_append (list, src_uri);
+	res = g_file_delete (src_file, NULL, &error);
 
-	retval = gnome_vfs_xfer_delete_list (list, GNOME_VFS_XFER_ERROR_MODE_ABORT,
-		GNOME_VFS_XFER_REMOVESOURCE, NULL, NULL);
+	if (!res) {
+		g_warning ("unable to delete [%s]: %s\n", TILE (tile)->uri,
+			   error->message);
+		g_error_free (error);
+	}
 
-	if (retval != GNOME_VFS_OK)
-		g_warning ("unable to delete [%s]\n", TILE (tile)->uri);
-
-	gnome_vfs_uri_unref (src_uri);
-	g_list_free (list);
+	g_object_unref (src_file);
 }
 
 static void
@@ -674,3 +625,44 @@ disown_spawned_child (gpointer user_data)
 	setsid  ();
 	setpgrp ();
 }
+
+static void
+open_with_default_trigger (Tile *tile, TileEvent *event, TileAction *action)
+{
+	DirectoryTilePrivate *priv = DIRECTORY_TILE_GET_PRIVATE (tile);
+	GList *uris = NULL;
+	gboolean res;
+	GdkAppLaunchContext *launch_context;
+	GError *error = NULL;
+
+	if (priv->default_app)
+	{
+		uris = g_list_append (uris, TILE (tile)->uri);
+		
+		launch_context = gdk_app_launch_context_new ();
+		gdk_app_launch_context_set_screen (launch_context,
+						   gtk_widget_get_screen (GTK_WIDGET (tile)));
+		gdk_app_launch_context_set_timestamp (launch_context,
+						      event->time);
+
+		res = g_app_info_launch_uris (priv->default_app, uris,
+					      G_APP_LAUNCH_CONTEXT (launch_context),
+					      &error);
+
+		if (!res) {
+			g_warning
+				("error: could not launch application with [%s]: %s\n",
+				 TILE (tile)->uri, error->message);
+			g_error_free (error);
+		}
+
+		g_list_free (uris);
+		g_object_unref (launch_context);
+	} else {
+		gchar *cmd;
+		cmd = string_replace_once (
+			get_slab_gconf_string (SLAB_FILE_MANAGER_OPEN_CMD), "FILE_URI", tile->uri);
+		spawn_process (cmd);
+		g_free (cmd);
+	}
+}
